@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2016 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -43,14 +43,8 @@ using namespace std;
 
 /* end doxygen comment */
 
-#if defined(_MSC_VER) || defined(__BORLANDC__)
-#  define isnan(d)  _isnan(d)
-#endif
-
 LIBSBML_CPP_NAMESPACE_BEGIN
 
-
-
 ASTNumber::ASTNumber (int type) :
    ASTBase   (type)
   , mExponential    ( NULL )
@@ -1729,7 +1723,7 @@ ASTNumber::setValue(double value, long value1)
 int 
 ASTNumber::setValue(double value)
 {
-  if (mExponential == NULL && mReal == NULL && !(isnan(value) > 0 || util_isInf(value) != 0))
+  if (mExponential == NULL && mReal == NULL && !(util_isNaN(value) > 0 || util_isInf(value) != 0))
   {
     std::string units = ASTNumber::getUnits();
     reset();
@@ -1738,7 +1732,7 @@ ASTNumber::setValue(double value)
     setType(AST_REAL);
     mReal->ASTBase::syncMembersFrom(this);
   }
-  else if ((isnan(value) > 0 || util_isInf(value) != 0) && mConstant == NULL) 
+  else if ((util_isNaN(value) > 0 || util_isInf(value) != 0) && mConstant == NULL) 
   {
     reset();
     mConstant = new ASTConstantNumberNode(AST_REAL);
